XML Resume Library To-Do List

# XML Résumé Library To-Do List

The XML Résumé Library copyrighted, © 2000-2002 by Sean Kelly. See the copying conditions, license, and disclaimer.

## What To Do

Below are a few suggestions. There's also a whole list of user-submitted at feature requests on the SourceForge project page.

- It would be nice to have an xmlresume-support distribution that includes all the necessary supporting software (fop, xalan, xerces, etc.) for first-time users. Then it's just a simple matter of setting a classpath and they're on their way.
- Create/improve translations. If you don't see your favorite language supported, please create an xsl file to do so.
- The `zip` element should be renamed to postalcode deprecated (bug 632271)
- Implement a web-accessible, do-it-yourself résumé generator, for those who aren't XML savvy.
- Format the date of birth, but parameterize it so that it can be formatted depending on preference. (While it may be traditional in some countries to include such information, I think it might invite age discrimination in other places.)
- The `<present/>` structure is kind of odd.